@@ -1,19 +1,7 @@
-# Copyright (C) 2014-2021 Greenbone Networks GmbH
+# -*- coding: utf-8 -*-
+# SPDX-FileCopyrightText: 2014-2023 Greenbone AG
 #
 # SPDX-License-Identifier: AGPL-3.0-or-later
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as
-# published by the Free Software Foundation, either version 3 of the
-# License, or (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public License
-# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 # pylint: disable=too-many-lines
 
@@ -124,7 +112,7 @@ class OSPDaemon:
         storage=None,
         max_scans=0,
         min_free_mem_scan_queue=0,
-        file_storage_dir='/var/run/ospd',
+        file_storage_dir='/run/ospd',
         max_queued_scans=0,
         **kwargs,
     ):  # pylint: disable=unused-argument
@@ -542,10 +530,10 @@ class OSPDaemon:
             except (AttributeError, ValueError) as message:
                 logger.error(message)
                 return
-            except (ssl.SSLError) as exception:
+            except ssl.SSLError as exception:
                 logger.debug('Error: %s', exception)
                 break
-            except (socket.timeout) as exception:
+            except socket.timeout as exception:
                 logger.debug('Request timeout: %s', exception)
                 break
 
