@@ -1,19 +1,7 @@
-# Copyright (C) 2014-2021 Greenbone Networks GmbH
+# -*- coding: utf-8 -*-
+# SPDX-FileCopyrightText: 2014-2023 Greenbone AG
 #
 # SPDX-License-Identifier: AGPL-3.0-or-later
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as
-# published by the Free Software Foundation, either version 3 of the
-# License, or (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public License
-# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 import logging
 import multiprocessing
@@ -29,7 +17,7 @@ from ospd.network import target_str_to_list
 from ospd.datapickler import DataPickler
 from ospd.errors import OspdCommandError
 
-LOGGER = logging.getLogger(__name__)
+logger = logging.getLogger(__name__)
 
 
 class ScanStatus(Enum):
@@ -77,9 +65,13 @@ class ScanCollection:
         )  # type: Optional[multiprocessing.managers.SyncManager]
         self.scans_table = dict()  # type: Dict
         self.file_storage_dir = file_storage_dir
+        self.scan_collection_lock = (
+            None
+        )  # type: Optional[multiprocessing.managers.Lock]
 
     def init(self):
         self.data_manager = multiprocessing.Manager()
+        self.scan_collection_lock = self.data_manager.RLock()
 
     def add_result(
         self,
@@ -138,7 +130,7 @@ class ScanCollection:
         if not hosts:
             return
 
-        LOGGER.debug(
+        logger.debug(
             '%s: Remove the following hosts from the target list, '
             'as they are already finished or are dead: %s',
             scan_id,
@@ -178,7 +170,7 @@ class ScanCollection:
     def set_host_finished(self, scan_id: str, hosts: List[str]) -> None:
         """Increase the amount of finished hosts which were alive."""
 
-        LOGGER.debug(
+        logger.debug(
             '%s: Setting the following hosts as finished: %s',
             scan_id,
             pformat(hosts),
@@ -192,7 +184,7 @@ class ScanCollection:
     def set_host_dead(self, scan_id: str, hosts: List[str]) -> None:
         """Increase the amount of dead hosts."""
 
-        LOGGER.debug(
+        logger.debug(
             '%s: Setting the following hosts as dead: %s',
             scan_id,
             pformat(hosts),
@@ -277,7 +269,7 @@ class ScanCollection:
         if not unpickled_scan_info:
             pickler.remove_file(scan_id)
             raise OspdCommandError(
-                'Not possible to unpickle stored scan info for %s' % scan_id,
+                f'Not possible to unpickle stored scan info for {scan_id}',
                 'start_scan',
             )
 
@@ -326,7 +318,11 @@ class ScanCollection:
         scan_info['start_time'] = int(time.time())
         scan_info['end_time'] = 0
 
-        scan_info_to_pickle = {'target': target, 'options': options, 'vts': vts}
+        scan_info_to_pickle = {
+            'target': target,
+            'options': options,
+            'vts': vts,
+        }
 
         if scan_id is None or scan_id == '':
             scan_id = str(uuid.uuid4())
@@ -336,7 +332,7 @@ class ScanCollection:
         try:
             scan_info_hash = pickler.store_data(scan_id, scan_info_to_pickle)
         except OspdCommandError as e:
-            LOGGER.error(e)
+            logger.error(e)
             return
 
         scan_info['scan_id'] = scan_id
@@ -353,12 +349,9 @@ class ScanCollection:
 
     def get_status(self, scan_id: str) -> ScanStatus:
         """Get scan_id scans's status."""
-        status = None
-        try:
-            status = self.scans_table[scan_id].get('status')
-        except KeyError:
-            LOGGER.error("Scan ID %s not found", scan_id)
-
+        status = self.scans_table.get(scan_id, {}).get('status', None)
+        if not status:
+            logger.warning("Scan ID %s not found", scan_id)
         return status
 
     def get_options(self, scan_id: str) -> Dict:
@@ -426,7 +419,7 @@ class ScanCollection:
             Count of excluded host.
         """
         exc_hosts_list = target_str_to_list(self.get_exclude_hosts(scan_id))
-        LOGGER.debug(
+        logger.debug(
             '%s: Excluded Hosts: %s',
             scan_id,
             pformat(exc_hosts_list),
@@ -435,7 +428,7 @@ class ScanCollection:
         finished_hosts_list = target_str_to_list(
             self.get_finished_hosts(scan_id)
         )
-        LOGGER.debug(
+        logger.debug(
             '%s: Finished Hosts: %s',
             scan_id,
             pformat(finished_hosts_list),
@@ -459,7 +452,7 @@ class ScanCollection:
                     invalid_exc_hosts += 1
 
         if invalid_exc_hosts > 0:
-            LOGGER.warning(
+            logger.warning(
                 "Please check the excluded host list. It contains hosts which "
                 "do not belong to the target. This warning can be ignored if "
                 "this was done on purpose (e.g. to exclude specific hostname)."
@@ -499,7 +492,7 @@ class ScanCollection:
             )
         except ZeroDivisionError:
             # Consider the case in which all hosts are dead or excluded
-            LOGGER.debug('%s: All hosts dead or excluded.', scan_id)
+            logger.debug('%s: All hosts dead or excluded.', scan_id)
             t_prog = ScanProgress.FINISHED.value
 
         return t_prog
@@ -521,7 +514,7 @@ class ScanCollection:
         try:
             target = self.scans_table[scan_id]['target'].get('hosts')
         except KeyError:
-            LOGGER.warning(
+            logger.warning(
                 '%s: Scan ID is in the scan table, but it was '
                 'not initialized.',
                 scan_id,
